Learn R Programming

randomForest (version 4.4-1)

importance: Extract variable importance measure

Description

This is the extractor function for variable importance measures as produced by randomForest.

Usage

## S3 method for class 'randomForest':
importance(x, type=NULL, class=NULL, scale=TRUE, ...)

Arguments

x
an object of class randomForest
type
either 1 or 2, specifying the type of importance measure (1=mean decrease in accuracy, 2=mean decrease in node impurity).
class
for classification problem, which class-specific measure to return.
scale
For permutation based measures, should the measures be divided their ``standard errors''?
...
not used.

Value

  • A (named) vector of importance measure, one for each predictor variable.

example

set.seed(4543) data(mtcars) mtcars.rf <- randomForest(mpg ~ ., data=mtcars, ntree=1000, keep=FALSE, importance=TRUE) importance(mtcars.rf) importance(mtcars.rf, type=1)

Details

See the documentation for randomForest for explanation of how the importance measures are computed.

See Also

randomForest, varImpPlot